==> amq-broker-operator-7.10.6-on-openshift-sources-rhel8.zip: amq-broker-operator-7.10.6-on-openshift-sources/pkg/client/clientset/versioned/typed/broker/v1beta1/broker_client.go <==
/*
Copyright 2020 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1beta1

import (
	v1beta1 "github.com/artemiscloud/activemq-artemis-operator/api/v1beta1"
	rest "k8s.io/client-go/rest"
)

type BrokerV1beta1Interface interface {
	RESTClient() rest.Interface
	ActiveMQArtemisesGetter
	ActiveMQArtemisSecuritiesGetter
}

// BrokerV1beta1Client is used to interact with features provided by the broker group.
type BrokerV1beta1Client struct {
	restClient rest.Interface
}

func (c *BrokerV1beta1Client) ActiveMQArtemises(namespace string) ActiveMQArtemisInterface {
	return newActiveMQArtemises(c, namespace)
}

// NewForConfig creates a new BrokerV1beta1Client for the given config.
func NewForConfig(c *rest.Config) (*BrokerV1beta1Client, error) {
	config := *c
	if err := setConfigDefaults(&config); err != nil {
		return nil, err
	}
	client, err := rest.RESTClientFor(&config)
	if err != nil {
		return nil, err
	}
	return &BrokerV1beta1Client{client}, nil
}

// NewForConfigOrDie creates a new BrokerV1beta1Client for the given config and
// panics if there is an error in the config.
func NewForConfigOrDie(c *rest.Config) *BrokerV1beta1Client {
	client, err := NewForConfig(c)
	if err != nil {
		panic(err)
	}
	return client
}

// New creates a new BrokerV1beta1Client for the given RESTClient.
func New(c rest.Interface) *BrokerV1beta1Client {
	return &BrokerV1beta1Client{c}
}

func setConfigDefaults(config *rest.Config) error {
	gv := v1beta1.GroupVersion
	config.GroupVersion = &gv
	config.APIPath = "/apis"

	if config.UserAgent == "" {
		config.UserAgent = rest.DefaultKubernetesUserAgent()
	}

	return nil
}

// RESTClient returns a RESTClient that is used to communicate
// with API server by this client implementation.
func (c *BrokerV1beta1Client) RESTClient() rest.Interface {
	if c == nil {
		return nil
	}
	return c.restClient
}

==> amq-broker-operator-7.12.1-on-openshift-sources-rhel8.zip: amq-broker-operator-7.12.1-on-openshift-sources/pkg/client/clientset/versioned/typed/broker/v1beta1/broker_client.go <==
/*
Copyright 2020 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1beta1

import (
	v1beta1 "github.com/artemiscloud/activemq-artemis-operator/api/v1beta1"
	rest "k8s.io/client-go/rest"
)

type BrokerV1beta1Interface interface {
	RESTClient() rest.Interface
	ActiveMQArtemisesGetter
	ActiveMQArtemisSecuritiesGetter
}

// BrokerV1beta1Client is used to interact with features provided by the broker group.
type BrokerV1beta1Client struct {
	restClient rest.Interface
}

func (c *BrokerV1beta1Client) ActiveMQArtemises(namespace string) ActiveMQArtemisInterface {
	return newActiveMQArtemises(c, namespace)
}

func (c *BrokerV1beta1Client) ActiveMQArtemisSecurities(namespace string) ActiveMQArtemisSecurityInterface {
	return newActiveMQArtemisSecurities(c, namespace)
}

// NewForConfig creates a new BrokerV1beta1Client for the given config.
func NewForConfig(c *rest.Config) (*BrokerV1beta1Client, error) {
	config := *c
	if err := setConfigDefaults(&config); err != nil {
		return nil, err
	}
	client, err := rest.RESTClientFor(&config)
	if err != nil {
		return nil, err
	}
	return &BrokerV1beta1Client{client}, nil
}

// NewForConfigOrDie creates a new BrokerV1beta1Client for the given config and
// panics if there is an error in the config.
func NewForConfigOrDie(c *rest.Config) *BrokerV1beta1Client {
	client, err := NewForConfig(c)
	if err != nil {
		panic(err)
	}
	return client
}

// New creates a new BrokerV1beta1Client for the given RESTClient.
func New(c rest.Interface) *BrokerV1beta1Client {
	return &BrokerV1beta1Client{c}
}

func setConfigDefaults(config *rest.Config) error {
	gv := v1beta1.GroupVersion
	config.GroupVersion = &gv
	config.APIPath = "/apis"

	if config.UserAgent == "" {
		config.UserAgent = rest.DefaultKubernetesUserAgent()
	}

	return nil
}

// RESTClient returns a RESTClient that is used to communicate
// with API server by this client implementation.
func (c *BrokerV1beta1Client) RESTClient() rest.Interface {
	if c == nil {
		return nil
	}
	return c.restClient
}
